@@ -103,21 +103,12 @@ sub serve_asset {
   my ($self, $c, $asset) = @_;
   my $d  = $self->default_headers;
   my $h  = $c->res->headers;
-  my $ct = $self->_types->type($asset->format);
+  my $ct = $self->_types->type($asset->format) || 'application/octet-stream';
 
-  if ($ct) {
-    $h->header($_ => $d->{$_}) for keys %$d;
-    $h->content_type($ct);
-    $self->SUPER::serve_asset($c, $asset->can('asset') ? $asset->asset : $asset);
-  }
-  else {
-    $h->content_type('text/css');
-    $c->render(text =>
-        qq(body:before{content:'"@{[$asset->url]}" is not processed.';font-size:32px;position:absolute;top:0;left:0;background:red;color:white;}\n)
-    );
-  }
-
-  return $self;
+  $h->header($_ => $d->{$_}) for keys %$d;
+  $h->content_type($ct);
+  $self->SUPER::serve_asset($c, $asset->can('asset') ? $asset->asset : $asset);
+  $self;
 }
 
 sub _already_downloaded {
@@ -198,7 +189,7 @@ sub _download {
   my $tx  = $self->ua->get($req_url);
   my $h   = $tx->res->headers;
 
-  if ($tx->error) {
+  if ($tx->res->is_error or $tx->error) {
     $self->ua->server->app->log->warn(
       "[AssetPack] Unable to download $req_url: @{[$tx->error->{message}]}");
     return undef;
@@ -216,7 +207,7 @@ sub _download {
   }
   if (my $ct = $h->content_type) {
     $ct =~ s!;.*$!!;
-    $attrs->{format} = $self->_types->detect($ct)->[0];
+    $attrs->{format} = $self->_types->detect($ct)->[0] unless $ct eq 'text/plain';
   }
 
   $attrs->{format} ||= $tx->req->url->path->[-1] =~ /\.(\w+)$/ ? $1 : undef;
@@ -305,6 +296,13 @@ L<Mojolicious::Static> implements the following new ones.
 
 Used to set default headers used by L</serve_asset>.
 
+=head2 paths
+
+  $paths = $self->paths;
+  $self = $self->paths([$app->home->rel_file("assets")]);
+
+See L<Mojolicious::Static/paths> for details.
+
 =head2 ua
 
   $ua = $self->ua;
